@@ -75,11 +75,13 @@ from yellowdog_cli.utils.settings import (
     NAMESPACE_OBJECT_STORE_PREFIX_SEPARATOR,
     PROP_ACCESS_DELEGATES,
     PROP_ADMIN_GROUP,
+    PROP_CREATED_BY_ID,
     PROP_CREATED_BY_USER_ID,
     PROP_CREATED_TIME,
     PROP_DELETABLE,
     PROP_ID,
     PROP_INSTANCE_PRICING,
+    PROP_REMAINING_HOURS,
     PROP_SUPPORTING_RESOURCE_CREATED,
     PROP_TRAITS,
     WARNING_STYLE,
@@ -1134,10 +1136,12 @@ def print_yd_object(
                     PROP_ID,
                     PROP_ACCESS_DELEGATES,
                     PROP_ADMIN_GROUP,
+                    PROP_CREATED_BY_ID,
                     PROP_CREATED_BY_USER_ID,
                     PROP_CREATED_TIME,
                     PROP_DELETABLE,
                     PROP_INSTANCE_PRICING,
+                    PROP_REMAINING_HOURS,
                     PROP_SUPPORTING_RESOURCE_CREATED,
                     PROP_TRAITS,
                 ]
