@@ -14,7 +14,8 @@ COMPUTE_REQUIREMENT_SECTION = "computeRequirement"  # No value
 CR_TAG = "requirementTag"  # String
 CSV_FILE = "csvFile"  # String
 CSV_FILES = "csvFiles"  # List of Strings
-DEPENDENT_ON = "dependentOn"  # String
+DEPENDENCIES = "dependencies"  # List of Strings
+DEPENDENT_ON = "dependentOn"  # String (Deprecated)
 DIRECTORY_NAME = "directoryName"  # String
 DOCKER_ENV = "dockerEnvironment"  # Dictionary
 DOCKER_OPTIONS = "dockerOptions"  # List
@@ -22,6 +23,7 @@ DOCKER_PASSWORD = "dockerPassword"  # String
 DOCKER_REGISTRY = "dockerRegistry"  # String
 DOCKER_USERNAME = "dockerUsername"  # String
 ENV = "environment"  # Dictionary
+ERROR_TYPES = "errorTypes"  # List of Strings
 EXCLUSIVE_WORKERS = "exclusiveWorkers"  # Boolean
 EXECUTABLE = "executable"  # String
 FILE_PATTERN = "filePattern"  # String
@@ -56,12 +58,15 @@ OUTPUTS_OTHER = "outputsOther"  # List of Dicts
 OUTPUTS_REQUIRED = "outputsRequired"  # List of Strings
 PARALLEL_BATCHES = "parallelBatches"  # Integer
 PRIORITY = "priority"  # Float
+PROCESS_EXIT_CODES = "processExitCodes"  # List of Ints
 PROVIDERS = "providers"  # List of Strings
 RAM = "ram"  # List of two Floats
 REGIONS = "regions"  # List of Strings
 REQUIRED = "required"  # Boolean
+RETRYABLE_ERRORS = "retryableErrors"  # List of Dicts
 SECRET = "secret"  # String
 SET_TASK_NAMES = "setTaskNames"  # Set to False to suppress task naming
+STATUSES_AT_FAILURE = "statusesAtFailure"  # List of Strings
 TARGET_INSTANCE_COUNT = "targetInstanceCount"  # Integer
 TASKS = "tasks"  # List of Tasks
 TASKS_PER_WORKER = "tasksPerWorker"  # Integer
@@ -109,6 +114,7 @@ WR_DATA = "workRequirementData"  # String
 WR_NAME = "name"  # String
 WR_TAG = "tag"  # String
 
+
 ALL_KEYS = [
     ADD_YD_ENV_VARS,
     ALWAYS_UPLOAD,
@@ -122,6 +128,7 @@ ALL_KEYS = [
     CR_TAG,
     CSV_FILE,
     CSV_FILES,
+    DEPENDENCIES,
     DEPENDENT_ON,
     DIRECTORY_NAME,
     DOCKER_ENV,
@@ -130,6 +137,7 @@ ALL_KEYS = [
     DOCKER_REGISTRY,
     DOCKER_USERNAME,
     ENV,
+    ERROR_TYPES,
     EXCLUSIVE_WORKERS,
     EXECUTABLE,
     FILE_PATTERN,
@@ -163,12 +171,15 @@ ALL_KEYS = [
     OUTPUTS_REQUIRED,
     PARALLEL_BATCHES,
     PRIORITY,
+    PROCESS_EXIT_CODES,
     PROVIDERS,
     RAM,
     REGIONS,
     REQUIRED,
+    RETRYABLE_ERRORS,
     SECRET,
     SET_TASK_NAMES,
+    STATUSES_AT_FAILURE,
     TARGET_INSTANCE_COUNT,
     TASKS,
     TASKS_PER_WORKER,
